@@ -41,37 +41,13 @@ use base qw( Log::Fine::Formatter );
 
 use Log::Fine;
 use Log::Fine::Formatter;
-use Log::Fine::Levels;
-
 use POSIX qw( strftime );
 
 =head1 METHODS
 
-=head2 format
+=head2 format($lvl, $msg, $skip)
 
-Formats the given message for the given level
-
-=head3 Parameters
-
-=over
-
-=item  * level
-
-Level at which to log (see L<Log::Fine::Levels>)
-
-=item  * message
-
-Message to log
-
-=item  * skip
-
-[ignored] Controls caller skip level
-
-=back
-
-=head3 Returns
-
-The formatted text string in the form:
+Returns the formatted message as follows:
 
   [TIMESTAMP] LEVEL MESSAGE
 
@@ -83,13 +59,14 @@ sub format
         my $self = shift;
         my $lvl  = shift;
         my $msg  = shift;
-        my $skip = shift;          # NOT USED
+        my $skip = shift;                         # NOT USED
+        my $lvls = Log::Fine->LOG_LEVELS;
 
         # return the formatted string
         return
-            sprintf("[%s] %-4s %s\n",
-                    $self->_formatTime(), $self->levelMap()->valueToLevel($lvl),
-                    $msg);
+                sprintf("[%s] %-4s %s\n",
+                        strftime($self->{timestamp_format}, localtime(time)),
+                        $lvls->[$lvl], $msg);
 
 }          # format()
 
@@ -139,11 +116,11 @@ L<http://search.cpan.org/dist/Log-Fine>
 
 =head1 REVISION INFORMATION
 
-  $Id: 539059026507586a1c8595acff8621e1c0a1f468 $
+  $Id: Basic.pm 49 2008-05-23 00:26:47Z cfuhrman $
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright (c) 2008, 2009, 2010 Christopher M. Fuhrman, 
+Copyright (c) 2008 Christopher M. Fuhrman, 
 All rights reserved.
 
 This program is free software licensed under the...
